from django import template

register = template.Library()


@register.filter(name="add_attr")
def add_attr(field, css):
    """Adds custom attributes (like class) to form fields without overwriting existing attributes."""
    # Retrieve existing attributes (if any)
    attrs = field.field.widget.attrs.copy()

    # Split the CSS string into key-value pairs
    definition = css.split(",")

    for d in definition:
        if ":" not in d:
            # If no key-value pair is provided, default to 'class'
            attrs["class"] = f"{attrs.get('class', '')} {d}".strip()
        else:
            # If a key-value pair is provided (e.g., 'data-test:123'), add it
            key, val = d.split(":")
            attrs[key.strip()] = val.strip()

    # Return the widget with the updated attributes
    return field.as_widget(attrs=attrs)
