from django import template
from django import forms

register = template.Library()


@register.filter(name="set_content")
def set_content(field, content):
    """Sets the content of input and textarea fields, and custom attributes like class, without overwriting existing attributes."""

    # Retrieve existing attributes (if any)
    attrs = field.field.widget.attrs.copy()

    # Check if the field is a text input or textarea
    is_input_or_textarea = isinstance(
        field.field.widget, (forms.widgets.TextInput, forms.widgets.Textarea)
    )

    # If the field is an input or textarea, set the content as value or text
    if is_input_or_textarea:
        attrs["value"] = content.strip()  # Set the value to the provided content

    if isinstance(field.field.widget, forms.widgets.Textarea):
        field.initial = content.strip()

    # Return the widget with the updated attributes
    return field.as_widget(attrs=attrs)
